@@ -17,7 +17,7 @@ class UnitOfWork(object):
         self.manager = manager
         self.reset()
 
-    def reset(self):
+    def reset(self, session=None):
         """
         Reset the internal state of this UnitOfWork object. Normally this is
         called after transaction has been committed or rolled back.
@@ -94,17 +94,33 @@ class UnitOfWork(object):
 
         self.make_versions(session)
 
+    def transaction_args(self, session):
+        args = {}
+        for plugin in self.manager.plugins:
+            args.update(plugin.transaction_args(self, session))
+        return args
+
     def create_transaction(self, session):
         """
         Create transaction object for given SQLAlchemy session.
 
         :param session: SQLAlchemy session object
         """
-        self.current_transaction = self.manager.transaction_cls()
-        self.manager.plugins.before_create_tx_object(self, session)
-        session.add(self.current_transaction)
-        self.manager.plugins.after_create_tx_object(self, session)
+        args = self.transaction_args(session)
 
+        Transaction = self.manager.transaction_cls
+        self.current_transaction = Transaction()
+
+        for key, value in args.items():
+            setattr(self.current_transaction, key, value)
+        if not self.version_session:
+            self.version_session = sa.orm.session.Session(
+                bind=session.connection()
+            )
+        self.version_session.add(self.current_transaction)
+        self.version_session.flush()
+        self.version_session.expunge(self.current_transaction)
+        session.add(self.current_transaction)
         return self.current_transaction
 
     def get_or_create_version_object(self, target):
@@ -169,7 +185,10 @@ class UnitOfWork(object):
 
         :param session: SQLAlchemy session object
         """
-        if not self.manager.options['versioning']:
+        if (
+            not self.manager.options['versioning'] or
+            self.manager.options['native_versioning']
+        ):
             return
 
         for key, operation in copy(self.operations).items():
