@@ -1,3 +1,4 @@
+from itertools import chain
 from inspect import isclass
 from collections import defaultdict
 
@@ -5,7 +6,11 @@ import sqlalchemy as sa
 from sqlalchemy.orm.attributes import get_history
 from sqlalchemy.orm.properties import ColumnProperty
 from sqlalchemy.orm.util import AliasedClass
-from sqlalchemy_utils.functions import naturally_equivalent, identity
+from sqlalchemy_utils.functions import (
+    get_primary_keys,
+    identity,
+    naturally_equivalent,
+)
 
 from .exc import ClassNotVersioned
 
@@ -275,7 +280,10 @@ def is_modified_or_deleted(obj):
     :param obj: SQLAlchemy declarative model object
     """
     session = sa.orm.object_session(obj)
-    return is_modified(obj) or obj in session.deleted
+    return is_versioned(obj) and (
+        is_modified(obj) or
+        obj in chain(session.deleted, session.new)
+    )
 
 
 def is_modified(obj):
@@ -333,6 +341,43 @@ def is_session_modified(session):
     )
 
 
+def count_versions(obj):
+    """
+    Return the number of versions given object has. This function works even
+    when obj has `create_models` and `create_tables` versioned settings
+    disabled.
+
+    ::
+
+        article = Article(name=u'Some article')
+
+        count_versions(article)  # 0
+
+        session.add(article)
+        session.commit()
+
+        count_versions(article)  # 1
+
+
+    :param obj: SQLAlchemy declarative model object
+    """
+    session = sa.orm.object_session(obj)
+    if session is None:
+        # If object is transient, we assume it has no version history.
+        return 0
+    manager = get_versioning_manager(obj)
+    table_name = manager.option(obj, 'table_name') % obj.__table__.name
+    criteria = [
+        '%s = %r' % (pk, getattr(obj, pk))
+        for pk in get_primary_keys(obj)
+    ]
+    query = 'SELECT COUNT(1) FROM %s WHERE %s' % (
+        table_name,
+        ' AND '.join(criteria)
+    )
+    return session.execute(query).scalar()
+
+
 def changeset(obj):
     """
     Return a humanized changeset for given SQLAlchemy declarative object. With
